@@ -7,7 +7,7 @@ use warnings;
 use Log::Any '$log';
 use Scalar::Util 'looks_like_number';
 
-our $VERSION = '1.24'; # VERSION
+our $VERSION = '1.25'; # VERSION
 
 our %SPEC;
 
@@ -46,7 +46,7 @@ Data::Unixish::sum - Sum numbers
 
 =head1 VERSION
 
-version 1.24
+version 1.25
 
 =head1 SYNOPSIS
 
@@ -64,29 +64,12 @@ In command line:
  | 5050 |
  '------'
 
-=head1 DESCRIPTION
-
-
-This module has L<Rinci> metadata.
-
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
+=head2 sum() -> [status, msg, result, meta]
 
-=head2 sum(%args) -> [status, msg, result, meta]
-
-Sum numbers.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<in> => I<any>
-
-=item * B<out> => I<any>
-
-=back
+No arguments.
 
 Return value:
 
@@ -98,7 +81,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2013 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
